/*
 * Copyright 2012 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import Ubuntu.Components.Popups 0.1

Item {
    id: tile
    height: childrenRect.height
    width: parent.width

    UbuntuShape {
        id: avatar
        radius: "medium"
        height: units.dp(48)
        width: units.dp(48)
        anchors {
            left: parent.left
            top: parent.top
            leftMargin: units.gu(1)
            topMargin: units.gu(1)
        }
        image: Image {
            anchors.fill: parent
            source: Qt.resolvedUrl(status_update.avatar)
            asynchronous: true
            fillMode: Image.PreserveAspectFit
        }
    }

    Item {
        anchors {
            left: avatar.right
            right: parent.right
            top: parent.top
            leftMargin: units.gu(1)
            bottomMargin: units.gu(1)
            rightMargin: units.gu(1)
        }

        height: status_update_content.height

        Column {
            id: status_update_content
            spacing: units.gu(1)
            height: childrenRect.height
            anchors {
                left: parent.left;
                right: parent.right
                bottomMargin: units.gu(2)
            }
            Label{
                id: sender
                text: status_update.sender
                fontSize: "medium"
                font.bold: true
                width: parent.width
            }
            Label {
                id: label
                text: status_update.message
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                width: parent.width - units.gu(3)
            }
            Label {
                id: likes
                text: (status_update.likes > 0) ? status_update.likes + " " + i18n.tr("people liked this") : ""
                width: parent.width
                fontSize: "small"
                color: "gray"
            }
        }

        Row {
            anchors.right: parent.right
            anchors.rightMargin: units.gu(1)
            anchors.top: parent.top
            spacing: units.gu(1)

            Label{
                id: time
                text: status_update.timestring
                fontSize: "small"
                color: "gray"
            }

        }
    }

    State { name: 'loaded'; when: moreDetails.status == Loader.Ready }


    MouseArea {
        anchors.fill: parent
        onClicked: {
            console.log ("DETAILS");
            moreDetails.source = "StatusUpdateTileDetails.qml";
            //status_update.height = childrenRect.height;
            //tile.height = status_update.height + moreDetails.height;
        }
    }
    Loader {
        id: moreDetails
        objectName: "moreDetails"
        height: childrenRect.height
        anchors {
            fill: parent
            top: tile.bottom
            left: parent.left
            right: parent.right
        }
        onStatusChanged: {
            if (moreDetails.status == Loader.Ready) {
                console.log('Loaded');
                tile.height = status_update.height + moreDetails.height;
            } else {
                console.log ("Unloaded");
                tile.height = status_update.height;
                moreDetails.source = "";
            }
        }
                
            
    }

}
